Module floyd_steinberg

Module floyd_steinberg 

Functions

effect
An implementation of the Floyd-Steinberg dithering algorithm. When a pixel’s error is calculated, the error is diffused down to other pixels with the following pattern (X is the current pixel, the numbers are fractions of 16):