Module pixel_sort
libeffectengine
0.1.1
Module pixel_
sort
Module Items
Functions
In libeffectengine::
effects
libeffectengine
::
effects
Module
pixel_
sort
Functions

effect
Sorts all pixels in an image above the image’s average brightness by their brightness value. Results in a tearing-like effect often used in video games like Cyberpunk 2077.