pub fn effect() -> Vec<u8> ⓘExpand description
“Quantizes” an image by adjusting the colors to fit a given palette. Each pixel’s color is checked for the lowest perceived distance to the color palette, then that new color is written to the new image instead.